@@ -4,7 +4,7 @@ from __future__ import annotations
 
 import asyncio
 from collections.abc import AsyncGenerator
-from contextlib import suppress
+from contextlib import asynccontextmanager, suppress
 from dataclasses import dataclass
 from datetime import timedelta
 from enum import Enum
@@ -178,7 +178,7 @@ class Gateway(AsyncUtilMixin, EventBase):
         self._devices: dict[EUI64, Device] = {}
         self._groups: dict[int, Group] = {}
         self.application_controller: ControllerApplication = None
-        self.coordinator_zha_device: Device = None
+        self.coordinator_zha_device: Device | None = None
 
         self.shutting_down: bool = False
         self._reload_task: asyncio.Task | None = None
@@ -275,6 +275,14 @@ class Gateway(AsyncUtilMixin, EventBase):
             await self.shutdown()
             raise
 
+    @asynccontextmanager
+    async def request_priority(
+        self, priority: t.PacketPriority | None
+    ) -> AsyncGenerator[None, None]:
+        """Context manager to request a priority for radio access."""
+        async with self.application_controller.request_priority(priority):
+            yield
+
     def connection_lost(self, exc: Exception) -> None:
         """Handle connection lost event."""
         _LOGGER.debug("Connection to the radio was lost: %r", exc)
@@ -371,7 +379,8 @@ class Gateway(AsyncUtilMixin, EventBase):
         async def fetch_updated_state() -> None:
             """Fetch updated state for mains powered devices."""
             if self.config.config.device_options.enable_mains_startup_polling:
-                await self.async_fetch_updated_state_mains()
+                async with self.request_priority(t.PacketPriority.LOW):
+                    await self.async_fetch_updated_state_mains()
             else:
                 _LOGGER.debug("Polling of mains powered devices at startup is disabled")
             _LOGGER.debug("Allowing polled requests")
@@ -436,9 +445,10 @@ class Gateway(AsyncUtilMixin, EventBase):
 
     def device_left(self, device: zigpy.device.Device) -> None:
         """Handle device leaving the network."""
-        zha_device: Device = self._devices.get(device.ieee)
+        zha_device = self._devices.get(device.ieee)
         if zha_device is not None:
             zha_device.on_network = False
+
         self.async_update_device(device, available=False)
         self.emit(
             ZHA_GW_MSG_DEVICE_LEFT, DeviceLeftEvent(ieee=device.ieee, nwk=device.nwk)
@@ -614,8 +624,9 @@ class Gateway(AsyncUtilMixin, EventBase):
         zha_device.available = True
         zha_device.on_network = True
 
-        await zha_device.async_configure()
-        await zha_device.async_initialize()
+        async with self.request_priority(t.PacketPriority.HIGH):
+            await zha_device.async_configure()
+            await zha_device.async_initialize()
 
         self.emit(
             ZHA_GW_MSG_DEVICE_FULL_INIT,
