@@ -30,6 +30,7 @@ from zha.zigbee.cluster_handlers.const import (
     ATTRIBUTE_VALUE,
     IKEA_AIR_PURIFIER_CLUSTER,
     IKEA_REMOTE_CLUSTER,
+    IKEA_SHORTCUT_V1_CLUSTER,
     INOVELLI_CLUSTER,
     LEGRAND_CABLE_OUTLET_CLUSTER,
     OSRAM_BUTTON_CLUSTER,
@@ -475,12 +476,32 @@ class IkeaAirPurifierClusterHandler(ClusterHandler):
 
 
 @registries.CLUSTER_HANDLER_ONLY_CLUSTERS.register(IKEA_REMOTE_CLUSTER)
-@registries.CLUSTER_HANDLER_REGISTRY.register(IKEA_REMOTE_CLUSTER)
-class IkeaRemoteClusterHandler(ClusterHandler):
+@registries.CLIENT_CLUSTER_HANDLER_REGISTRY.register(IKEA_REMOTE_CLUSTER)
+class IkeaRemoteClientClusterHandler(ClientClusterHandler):
     """Ikea Matter remote cluster handler."""
 
     REPORT_CONFIG = ()
 
+    def cluster_command(self, tsn, command_id, args):
+        """Handle a cluster command received on this cluster."""
+        # Do not emit ZHA events when receiving a client command, this duplicates the
+        # existing event sent by the quirk.
+        pass
+
+
+@registries.CLUSTER_HANDLER_ONLY_CLUSTERS.register(IKEA_SHORTCUT_V1_CLUSTER)
+@registries.CLIENT_CLUSTER_HANDLER_REGISTRY.register(IKEA_SHORTCUT_V1_CLUSTER)
+class IkeaSymfoniskRemoteClientClusterHandler(ClientClusterHandler):
+    """Ikea Symfonisk remote cluster handler."""
+
+    REPORT_CONFIG = ()
+
+    def cluster_command(self, tsn, command_id, args):
+        """Handle a cluster command received on this cluster."""
+        # Do not emit ZHA events when receiving a client command, this duplicates the
+        # existing event sent by the quirk.
+        pass
+
 
 @registries.CLUSTER_HANDLER_REGISTRY.register(
     DoorLock.cluster_id, XIAOMI_AQARA_VIBRATION_AQ1
@@ -507,7 +528,7 @@ class SonoffPresenceSenorClusterHandler(ClusterHandler):
 class DanfossThermostatClusterHandler(ThermostatClusterHandler):
     """Thermostat cluster handler for the Danfoss TRV and derivatives."""
 
-    REPORT_CONFIG = (
+    REPORT_CONFIG = (  # type: ignore[assignment]
         *ThermostatClusterHandler.REPORT_CONFIG,
         AttrReportConfig(attr="open_window_detection", config=REPORT_CONFIG_DEFAULT),
         AttrReportConfig(attr="heat_required", config=REPORT_CONFIG_ASAP),
