@@ -6,7 +6,7 @@ from __future__ import annotations
 
 import asyncio
 from collections import defaultdict
-from collections.abc import Callable, Iterable
+from collections.abc import Callable, Iterable, Iterator
 import copy
 import dataclasses
 from dataclasses import dataclass
@@ -66,10 +66,12 @@ from zha.application.const import (
 )
 from zha.application.helpers import convert_to_zcl_values, convert_zcl_value
 from zha.application.platforms import (
+    BaseEntity,
     BaseEntityInfo,
     EntityStateChangedEvent,
     PlatformEntity,
 )
+from zha.application.platforms.update import BaseFirmwareUpdateEntity
 from zha.const import STATE_CHANGED
 from zha.event import EventBase
 from zha.exceptions import ZHAException
@@ -924,6 +926,8 @@ class Device(LogMixin, EventBase):
                 entity._attr_fallback_name = meta.new_fallback_name
 
     def _discover_new_entities(self) -> None:
+        new_entities: Iterator[BaseEntity]
+
         if self.is_active_coordinator:
             new_entities = discovery.DEVICE_PROBE.discover_coordinator_device_entities(
                 self
@@ -995,11 +999,13 @@ class Device(LogMixin, EventBase):
             if platform != Platform.UPDATE:
                 continue
 
+            assert isinstance(entity, BaseFirmwareUpdateEntity)
             self._firmware_version = entity.installed_version
 
             def entity_update_listener(event: EntityStateChangedEvent) -> None:
                 """Listen to firmware update entity changes."""
                 entity = self.get_platform_entity(event.platform, event.unique_id)
+                assert isinstance(entity, BaseFirmwareUpdateEntity)
                 self.async_update_firmware_version(entity.installed_version)
 
             self._on_remove_callbacks.append(
@@ -1500,6 +1506,7 @@ class Device(LogMixin, EventBase):
             info_object = dataclasses.asdict(platform_entity.info_object)
             info_object["cluster_handlers"].sort(key=lambda i: i["unique_id"])
             info_object["migrate_unique_ids"] = list(info_object["migrate_unique_ids"])
+            info_object["device_ieee"] = str(info_object["device_ieee"])
 
             for cluster_handler_info in info_object["cluster_handlers"]:
                 cluster_info = cluster_handler_info["cluster"]
@@ -1507,12 +1514,17 @@ class Device(LogMixin, EventBase):
                 if cluster_info is not None:
                     cluster_info.pop("commands", None)
 
-            info["zha_lib_entities"][platform].append(
-                {
-                    "info_object": info_object,
-                    "state": platform_entity.state,
-                }
-            )
+            obj: dict[str, Any] = {
+                "info_object": info_object,
+                "state": platform_entity.state,
+            }
+
+            if platform_entity.extra_state_attribute_names is not None:
+                obj["extra_state_attributes"] = sorted(
+                    platform_entity.extra_state_attribute_names
+                )
+
+            info["zha_lib_entities"][platform].append(obj)
 
         topology = self.gateway.application_controller.topology
         info["neighbors"] = [
